@@ -1,7 +1,7 @@
 package Parse::Netstat;
 
-our $DATE = '2014-12-02'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2017-02-09'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -101,7 +101,7 @@ sub parse_netstat {
 }
 
 1;
-# ABSTRACT: Parse netstat output
+# ABSTRACT: Parse the output of "netstat" command
 
 __END__
 
@@ -111,11 +111,11 @@ __END__
 
 =head1 NAME
 
-Parse::Netstat - Parse netstat output
+Parse::Netstat - Parse the output of "netstat" command
 
 =head1 VERSION
 
-This document describes version 0.11 of Parse::Netstat (from Perl distribution Parse-Netstat), released on 2014-12-02.
+This document describes version 0.13 of Parse::Netstat (from Perl distribution Parse-Netstat), released on 2017-02-09.
 
 =head1 SYNOPSIS
 
@@ -125,13 +125,14 @@ This document describes version 0.11 of Parse::Netstat (from Perl distribution P
 =head1 FUNCTIONS
 
 
-=head2 parse_netstat(%args) -> [status, msg, result, meta]
+=head2 parse_netstat
+
+Usage:
+
+ parse_netstat(%args) -> [status, msg, result, meta]
 
 Parse the output of "netstat" command.
 
-Examples:
-
- parse_netstat();
 This program support several flavors of netstat. The default flavor is C<linux>.
 Use C<--flavor> to select which flavor you want.
 
@@ -141,6 +142,8 @@ a single flavor are supported, please see the sample parse output for each
 flavor (in corresponding C<Parse::Netstat::*> per-flavor module) you want to use
 and adjust accordingly.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -170,8 +173,6 @@ Parse Unix socket connections.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -181,13 +182,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
-
-=head1 SEE ALSO
-
-Parse::Netstat::* for per-flavor notes and sample outputs.
-
-L<App::ParseNetstat> provides a CLI for this module.
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -195,7 +190,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Parse-Nets
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Parse-Netstat>.
+Source repository is at L<https://github.com/perlancar/perl-Parse-Netstat>.
 
 =head1 BUGS
 
@@ -205,13 +200,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+Parse::Netstat::* for per-flavor notes and sample outputs.
+
+L<parse-netstat> from L<App::ParseNetstat> is a CLI for this module.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2015, 2014, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
