@@ -1,7 +1,7 @@
 package Parse::Netstat::freebsd;
 
-our $DATE = '2014-12-02'; # DATE
-our $VERSION = '0.11'; # VERSION
+our $DATE = '2017-02-09'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -59,10 +59,12 @@ sub parse_netstat {
     for my $line (split /^/, $output) {
         $i++;
         my %k;
-        if ($line =~ /^tcp/ && $tcp) {
+        if ($line =~ /^Registered kernel control modules/) {
+            $in_unix = 0;
+        } elsif ($line =~ /^tcp/ && $tcp) {
             #Proto Recv-Q Send-Q Local Address               Foreign Address             State       PID/Program name
             #tcp4       0      0 192.168.1.33.632       192.168.1.10.2049      CLOSED
-            $line =~ m!^(?P<proto>tcp[46]?) \s+ (?P<recvq>\d+) \s+ (?P<sendq>\d+)\s+
+            $line =~ m!^(?P<proto>tcp(?:4|6|46)?) \s+ (?P<recvq>\d+) \s+ (?P<sendq>\d+)\s+
                        (?P<local_host>\S+?)[:.](?P<local_port>\w+)\s+
                        (?P<foreign_host>\S+?)[:.](?P<foreign_port>\w+|\*)\s+
                        (?P<state>\S+) (?: \s+ (?:
@@ -74,7 +76,7 @@ sub parse_netstat {
         } elsif ($line =~ /^udp/ && $udp) {
             #Proto Recv-Q Send-Q Local Address          Foreign Address        (state)
             #udp4       0      0 *.879                  *.*
-            $line =~ m!^(?P<proto>udp[46]?) \s+ (?P<recvq>\d+) \s+ (?P<sendq>\d+) \s+
+            $line =~ m!^(?P<proto>udp(?:4|6|46)?) \s+ (?P<recvq>\d+) \s+ (?P<sendq>\d+) \s+
                        (?P<local_host>\S+?)[:.](?P<local_port>\w+|\*)\s+
                        (?P<foreign_host>\S+?)[:.](?P<foreign_port>\w+|\*)
                        (?: \s+
@@ -103,7 +105,7 @@ sub parse_netstat {
         } elsif ($in_unix_header) {
             $in_unix_header = 0;
             $in_unix++;
-        } elsif ($line =~ /^Active UNIX domain sockets/) {
+        } elsif ($line =~ /^Active (UNIX|LOCAL \(UNIX\)) domain sockets/) {
             $in_unix_header++;
         } else {
             next;
@@ -129,7 +131,7 @@ Parse::Netstat::freebsd - Parse the output of FreeBSD "netstat" command
 
 =head1 VERSION
 
-This document describes version 0.11 of Parse::Netstat::freebsd (from Perl distribution Parse-Netstat), released on 2014-12-02.
+This document describes version 0.13 of Parse::Netstat::freebsd (from Perl distribution Parse-Netstat), released on 2017-02-09.
 
 =head1 SYNOPSIS
 
@@ -875,7 +877,11 @@ Sample result:
 =head1 FUNCTIONS
 
 
-=head2 parse_netstat(%args) -> [status, msg, result, meta]
+=head2 parse_netstat
+
+Usage:
+
+ parse_netstat(%args) -> [status, msg, result, meta]
 
 Parse the output of FreeBSD "netstat" command.
 
@@ -885,6 +891,8 @@ listening and non-listening socket) option or without.
 
 Tested with FreeBSD 10.1's netstat.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -907,8 +915,6 @@ Whether to parse Unix socket connections.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -918,7 +924,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -926,7 +932,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Parse-Nets
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Parse-Netstat>.
+Source repository is at L<https://github.com/perlancar/perl-Parse-Netstat>.
 
 =head1 BUGS
 
@@ -942,7 +948,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2017, 2015, 2014, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
